==> nextcloud-21.0.4.tgz: nextcloud/apps/oauth2/l10n/sc.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Su cliente tuo no est autorizadu a si connètere. Pro praghere, informa s'amministradore de su cliente tuo.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : " S'URL tuo pro torrare a deretare tocat chi siat unu URL cumpretu, pro nàrrere: https://sudomìniutuo.com/caminu",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Cunsenti s'autenticatzione cumpatìbile cun OAuth2 dae àteras aplicatziones in sa rete.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "S'aplicatzione OAuth2 cunsentit a is amministradores de cunfigurare sa protzedura de autenticatzione integrada pro cunsentire fintzas s'autenticatzione cumpatìbile cun OAuth2 dae àteras aplicatziones in sa rete.",
    "OAuth 2.0 clients" : "Clientes de OAuth 2.0 ",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 cunsentit a is zservìtzios de foras de pedire s'atzessu a {instanceName}.",
    "Add client" : "Agiunghe cliente",
    "Name" : "Nùmene",
    "Redirection URI" : "URI de torrada a deretare",
    "Add" : "Agiunghe",
    "Client Identifier" : "Identificadore cliente",
    "Secret" : "Segretu",
    "Show client secret" : "Mustra su segretu de su cliente",
    "Delete" : "Cantzella"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/oauth2/l10n/sc.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Su cliente tuo no est autorizadu a si connètere. Pro praghere, informa s'amministradore de su cliente tuo.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : " S'URL tuo pro torrare a deretare tocat chi siat unu URL cumpretu, pro nàrrere: https://sudomìniutuo.com/caminu",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Cunsenti s'autenticatzione cumpatìbile cun OAuth2 dae àteras aplicatziones in sa rete.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "S'aplicatzione OAuth2 cunsentit a is amministradores de cunfigurare sa protzedura de autenticatzione integrada pro cunsentire fintzas s'autenticatzione cumpatìbile cun OAuth2 dae àteras aplicatziones in sa rete.",
    "OAuth 2.0 clients" : "Clientes de OAuth 2.0 ",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 cunsentit a is zservìtzios de foras de pedire s'atzessu a {instanceName}.",
    "Name" : "Nùmene",
    "Redirection URI" : "URI de torrada a deretare",
    "Client Identifier" : "Identificadore cliente",
    "Secret key" : "Crae segreta",
    "Add client" : "Agiunghe cliente",
    "Add" : "Agiunghe",
    "Show client secret" : "Mustra su segretu de su cliente",
    "Delete" : "Cantzella",
    "Secret" : "Segretu"
},
"nplurals=2; plural=(n != 1);");
